@@ -19,6 +19,7 @@ import json as json_import
 from os import getenv, environ, getcwd
 from os.path import isfile, join, expanduser
 from typing import List, Union
+from urllib.parse import urlparse, parse_qs
 
 import dateutil.parser as date_parser
 
@@ -116,6 +117,40 @@ def string_to_datetime(string: str) -> datetime.datetime:
     return val.replace(tzinfo=datetime.timezone.utc)
 
 
+def string_to_datetime_list(string_list: List[str]) -> List[datetime.datetime]:
+    """De-serializes each string in a list to a datetime.
+
+    Args:
+        string_list: list of strings containing datetime in iso8601 format.
+
+    Returns:
+        the de-serialized list of strings as a list of datetime objects.
+    """
+    if not isinstance(string_list, list):
+        raise ValueError("Invalid argument type: " + str(type(string_list))
+            + ". Argument string_list must be of type List[str]")
+    datetime_list = []
+    for string_val in string_list:
+        datetime_list.append(string_to_datetime(string_val))
+    return datetime_list
+
+def datetime_to_string_list(datetime_list: List[datetime.datetime]) -> List[str]:
+    """Convert a list of datetime objects to a list of strings.
+
+    Args:
+        datetime_list: The list of datetime objects.
+
+    Returns:
+        list of datetimes serialized as strings in iso8601 format.
+    """
+    if not isinstance(datetime_list, list):
+        raise ValueError("Invalid argument type: " + str(type(datetime_list))
+            + ". Argument datetime_list must be of type List[datetime.datetime]")
+    string_list = []
+    for datetime_val in datetime_list:
+        string_list.append(datetime_to_string(datetime_val))
+    return string_list
+
 def date_to_string(val: datetime.date) -> str:
     """Convert a date object to string.
 
@@ -141,6 +176,29 @@ def string_to_date(string: str) -> datetime.date:
     """
     return date_parser.parse(string).date()
 
+def get_query_param(url_str: str, param: str) -> str:
+    """Return a query parameter value from url_str
+
+    Args:
+        url_str: the URL from which to extract the query
+            parameter value
+        param: the name of the query parameter whose value
+            should be returned
+
+    Returns:
+        the value of the `param` query parameter as a string
+
+    Raises:
+        ValueError: if errors are encountered parsing `url_str`
+    """
+    if not url_str:
+        return None
+    url = urlparse(url_str)
+    if not url.query:
+        return None
+    query = parse_qs(url.query, strict_parsing=True)
+    values = query.get(param)
+    return values[0] if values else None
 
 def convert_model(val: any) -> dict:
     """Convert a model object into an equivalent dict.
